<?php

namespace App\Admin\Controllers\OrdersManagement;

use App\Admin\Actions\backstage\Orders\Evaluate;
use App\Admin\Actions\backstage\Orders\RefundApplicationAction;
use App\Admin\Actions\backstage\Refund\RefundCompleteAction;
use App\Admin\Actions\backstage\Refund\RefundServicePackAction;
use App\Models\Order;
use App\Admin\Actions\backstage\Orders\OrderDetails;
use App\Models\OrderPack;
use App\Models\Organization;
use App\Models\ServicePack;
use Encore\Admin\Widgets\Table;
use Encore\Admin\Controllers\AdminController;
use App\Admin\Actions\backstage\User\MapDepot;
use App\Admin\Actions\backstage\User\Suggests;
use Encore\Admin\Form;
use Encore\Admin\Grid;
use Encore\Admin\Show;

class BookingOrderController extends AdminController
{
    /**
     * Title for current resource.
     *
     * @var string
     */
    protected $title = '预约订单';

    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        $grid = new Grid(new Order());
        $grid->disableCreateButton();
        $grid->model()->wherein('product_type',[3,4,5]);

        //筛选

        $grid->filter(function ($filter){
            $filter->disableIdFilter();
            $filter->column(1/2, function ($filter) {
                $filter->like('user.nickname','用户姓名');
                $filter->like('docter.name','医生姓名');
                $filter->like('orderPatient.name','患者姓名');
                $filter->equal('orderPatient.patient_phone','患者电话');
                $filter->equal('product_type','预约类型')->radio(
                    [
                        ''=>'不限',
                        3=>'门诊预约',
                        4=>'疫苗接种预约',
                        5=>'儿保预约'
                    ]
                );
            });
            $filter->column(1/2, function ($filter) {
                $filter->equal('order_status','订单状态')->radio(
                    [
                        ''=>'不限',
                        1=>'未支付',
                        2=>'待接单',
                        3=>'进行中',
                        4=>'已完成',
                        5=>'已取消',
                        6=>'已超时',
                        7=>'已预约',
                    ]
                );
                $filter->equal('payment_status','支付状态')->radio(
                    [
                        ''=>'不限',
                        1=>'待付款',
                        2=>'已付款',
                        3=>'退款中',
                        4=>'已退款',
                        5=>'待退款',
                    ]
                );
                $filter->timestampBetween('payment_time', "支付时间")->datetime();
                $filter->timestampBetween('end_time', "订单完成时间")->datetime();
                $filter->between('created_at','创建时间')->datetime();

            });
        });

        $grid->actions(function ($actions){
            // 1.门诊预约和儿保预约有退款操作
            $actions->disableView();
            $actions->disableEdit();
            $actions->disableDelete();
            if ($actions->row->product_type == 3 || $actions->row->product_type == 5)
            {
                if (
                    //已取消 待退款
                    ($actions->row->order_status == 5 && $actions->row->payment_status == 5)||
                    //已超时 已支付
                    ($actions->row->order_status == 6 && $actions->row->payment_status == 2)){
                        //判断是否是服务包支付 是的话走退次数的逻辑，不是的话走退余额的操作
                        if ($actions->row->payment_type == 3)
                        {
                            $actions->add(new RefundServicePackAction());
                        }else
                        {
                            $actions->add(new RefundApplicationAction());
                        }
                }
            }
        });
        $grid->export(function ($export) {
            $export->filename('预约订单');
    });
        $status_arr = Order::getStatus();
        $grid->model()->orderBy('id','desc');
        $grid->column('created_at','创建时间')->hide();
        $grid->column('id', __('Id'))->sortable();
        $grid->column('user.nickname', __('用户姓名'));
        $grid->column('docter.name', __('医生姓名'));
        $grid->column('orderPatient.name', __('患者姓名'));
        $grid->column('orderPatient.patient_phone', __('患者电话'));
        $grid->column('organization_id', __('预约机构'))->display(function ($org_id){
            $name = Organization::where('id',$org_id)->value('name');
            return $name;
        });
        $grid->column('orderPatient.appoint_start_time', __('预约日期'))->display(function ($time){
            return date('Y-m-d H:i:s',$time);
        });
        $grid->column('product_type', __('产品类型'))->using([3=>'门诊预约',4=>'疫苗接种预约',5=>'儿保预约']);
        $grid->column('payment_type', __('支付方式'))->display(function ($payment_type){
            if ($payment_type == 1)
            {
                return '微信支付';
            }
            if ($payment_type == 2){
                return '余额支付';
            }
            if ($payment_type == 3){
                $order_pack_id = OrderPack::where('id',$this->pay_order_pack_id)->value('service_pack_id');
                $name = ServicePack::where('id',$order_pack_id)->value('name');
                return '服务包支付('.$name.')';
            }
        });
        $grid->column('order_status', __('订单状态'))->display(function ($w) use ($status_arr) {
            $info = $status_arr[intval($w)];
            if($w == 1 || $w == 2){
                return '<span class="label label-warning">'.$info.'</span>';
            } else if( $w == 4 ){
                return '<span class="label label-success">'.$info.'</span>';
            } else if($w == 7 || $w == 3 ){
                return '<span class="label label-info">'.$info.'</span>';
            } else if($w == 6){
                return '<span class="label label-danger">'.$info.'</span>';
            } else {
                return '<span class="label label-default">'.$info.'</span>';
            }
        });;
        $grid->column('payment_status', __('支付状态'))->using([1=>'待付款',2=>'已付款',3=>'退款中',4=>'已退款',5=>'待退款'])->label([1=>'warning',2=>'success',3=>'info',4=>'danger',5=>'default']);;
        $grid->column('total_amount', __('订单总金额'))->display(function ($money){
            return $money/100;
        });
        $grid->column('payment_amount', __('用户实际支付的金额'))->display(function ($money){
            return $money/100;
        });
        $grid->column('discount_amount', __('折扣金额'))->display(function ($money){
            return $money/100;
        });
        $grid->column('order_notes', __('订单备注'));
        $grid->column('payment_time', __('支付时间'))->display(function ($time){
            if ($time == 0)
            {
                return '';
            }else
            {
                return date('Y-m-d H:i:s',$time);
            }
        });
        $grid->column('end_time', __('订单完成时间'))->display(function ($time){
            if ($time == 0)
            {
                return '';
            }else
            {
                return date('Y-m-d H:i:s',$time);
            }
        });
        return $grid;
    }

    /**
     * Make a show builder.
     *
     * @param mixed $id
     * @return Show
     */
    protected function detail($id)
    {
        $show = new Show(Order::findOrFail($id));
        $show->field('id', __('Id'));
        $show->field('user_id', __('用户id'));
        $show->field('user.nickname', __('用户姓名'));
        $show->field('docter_id', __('医生id'));
        $show->field('docter.name', __('医生姓名'));
        $show->field('patient_id', __('患者id'));
        $show->field('orderPatient.name', __('患者姓名'));
        $show->field('organization_id', __('机构id'));
        $show->field('organization.name', __('机构名'));
        $show->field('order_sn', __('订单号'));
        $show->field('product_type', __('产品类型'))->using([3=>'门诊预约',4=>'疫苗接种预约',5=>'儿保预约']);
        $show->field('payment_type', __('支付类型'))->using([1=>'微信支付',2=>'余额支付']);
        $show->field('order_status', __('订单状态'))->using([1=>'未支付',2=>'待接单',3=>'进行中',4=>'已完成',5=>'已取消']);
        $show->field('payment_status', __('支付状态'))->using([1=>'待付款',2=>'已付款',3=>'退款中',4=>'已退款']);
        $show->field('total_amount', __('	订单总金额'))->as(function ($money){
            return $money/100;
        });
        $show->field('payment_amount', __('用户实际支付的金额'))->as(function ($money){
            return $money/100;
        });
        $show->field('discount_amount', __('折扣金额'))->as(function ($money){
            return $money/100;
        });
        $show->field('payment_time', __('支付时间'))->as(function ($time){
            if($time == 0)
            {
                return '';
            }
            else
            {
                return date('Y-m-d H:i:s',$time);
            }
        });
        $show->field('receiving_time', __('接单时间'))->as(function ($time){
            if($time == 0)
            {
                return '';
            }
            else
            {
                return date('Y-m-d H:i:s',$time);
            }
        });
        $show->field('end_time', __('订单完成时间'))->as(function ($time){
            if($time == 0)
            {
                return '';
            }
            else
            {
                return date('Y-m-d H:i:s',$time);
            }
        });
        $show->field('created_at', __('创建时间'));
        $show->field('updated_at', __('更新时间'));

        return $show;
    }

    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {
        $form = new Form(new Order());

        $form->number('user_id', __('User id'));
        $form->number('docter_id', __('Docter id'));
        $form->number('patient_id', __('Patient id'));
        $form->number('organization_id', __('Organization id'));
        $form->text('order_sn', __('Order sn'));
        $form->switch('payment_type', __('Payment type'))->default(1);
        $form->switch('product_type', __('Product type'))->default(1);
        $form->switch('order_status', __('Order status'))->default(1);
        $form->switch('payment_status', __('Payment status'))->default(1);
        $form->number('total_amount', __('Total amount'));
        $form->number('payment_amount', __('Payment amount'));
        $form->number('discount_amount', __('Discount amount'));
        $form->number('payment_time', __('Payment time'));
        $form->number('outtime', __('Outtime'));
        $form->number('receiving_time', __('Receiving time'));

        return $form;
    }
}
