<?php

namespace App\Admin\Controllers\OrdersManagement;

use App\Admin\Actions\backstage\Orders\Evaluate;
use App\Admin\Actions\backstage\Orders\Message;
use App\Admin\Actions\backstage\Orders\OrderDetails;
use App\Admin\Actions\backstage\Orders\OrderOpinion;
use App\Admin\Actions\backstage\Orders\RefundApplicationAction;
use App\Admin\Actions\backstage\User\MapDepot;
use App\Admin\Actions\backstage\User\Suggests;
use App\Models\ImMessage;
use App\Models\Order;
use App\Models\OrderPack;
use App\Models\ServicePack;
use Encore\Admin\Layout\Content;
use Encore\Admin\Widgets\Table;
use Encore\Admin\Controllers\AdminController;
use Encore\Admin\Form;
use Encore\Admin\Grid;
use Encore\Admin\Show;
use Illuminate\Http\Request;
use Encore\Admin\Facades\Admin;

class ConsultingOrdersController extends AdminController
{
    /**
     * Title for current resource.
     *
     * @var string
     */
    protected $title = '咨询订单';

    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        $grid = new Grid(new Order());
        $grid->disableCreateButton();
        $grid->model()->wherein('product_type',[1,2]);
        //筛选
        $grid->filter(function ($filter){
            $filter->disableIdFilter();
            $filter->column(1/2, function ($filter) {
                $filter->like('user.nickname','用户姓名');
                $filter->like('docter.name','医生姓名');
                $filter->like('orderPatient.name','患者姓名');
                $filter->equal('product_type','产品类型')->radio(
                    [
                        ''=>'不限',
                        1=>'电话咨询',
                        2=>'图文咨询',
                    ]
                );
                $filter->in('evaluate.score','评分')->checkbox([
                    1    => 1,
                    2    => 2,
                    3    => 3,
                    4    => 4,
                    5    => 5,
                ]);
            });
            $filter->column(1/2, function ($filter) {
                $filter->equal('order_status','订单状态')->radio(
                    [
                        ''=>'不限',
                        1=>'未支付',
                        2=>'待接单',
                        3=>'进行中',
                        4=>'已完成',
                        5=>'已取消',
                        6=>'已超时'
                    ]
                );
                $filter->equal('payment_status','支付状态')->radio(
                    [
                        ''=>'不限',
                        1=>'待付款',
                        2=>'已付款',
                        3=>'退款中',
                        4=>'已退款',
                        5=>'待退款',
                    ]
                );
                $filter->timestampBetween('payment_time', "支付时间")->datetime();
                $filter->timestampBetween('receiving_time', "接单时间")->datetime();
                $filter->timestampBetween('end_time', "订单完成时间")->datetime();
                // 设置datetime类型
                $filter->between('created_at','创建时间')->datetime();
            });
        });
        //操作
        $grid->actions(function ($actions){
            $actions->disableView();
            $actions->disableEdit();
            $actions->disableDelete();
            $actions->add(new OrderOpinion());
            if ($actions->row->order_status == 4)
            {
                $actions->add(new Message());
            }
        });
        $grid->export(function ($export) {
            $export->filename('咨询订单');
            $export->except(['is_evaluates']);
        });
        $status_arr = Order::getStatus();
        $grid->model()->orderBy('id','desc');
        $grid->column('id', __('Id'))->sortable();
        $grid->column('user.nickname', __('用户姓名'));
        $grid->column('docter.name', __('医生姓名'));
        $grid->column('orderPatient.name', __('患者姓名'));
        $grid->column('orderPatient.patient_phone', __('患者电话'));
        $grid->column('orderPatient.symptoms', __('患者描述'));
        $grid->column('product_type', __('产品类型'))->using([1=>'电话咨询',2=>'图文咨询',3=>'门诊预约',4=>'疫苗接种预约',5=>'儿保预约',6=>'服务包',7=>'充值',8=>'快速预约']);
        $grid->column('payment_type', __('支付方式'))->display(function ($payment_type){
            if ($payment_type == 1)
            {
                return '微信支付';
            }
            if ($payment_type == 2){
                return '余额支付';
            }
            if ($payment_type == 3){
                $order_pack_id = OrderPack::where('id',$this->pay_order_pack_id)->value('service_pack_id');
                $name = ServicePack::where('id',$order_pack_id)->value('name');
                return '服务包支付('.$name.')';
            }
        });
        $grid->column('order_status', __('订单状态'))->display(function ($w) use ($status_arr) {
            $info = $status_arr[intval($w)];
            if($w == 1 || $w == 2){
                return '<span class="label label-warning">'.$info.'</span>';
            } else if( $w == 4 ){
                return '<span class="label label-success">'.$info.'</span>';
            } else if($w == 7 || $w == 3 ){
                return '<span class="label label-info">'.$info.'</span>';
            } else if($w == 6){
                return '<span class="label label-danger">'.$info.'</span>';
            } else {
                return '<span class="label label-default">'.$info.'</span>';
            }
        });
        $grid->column('payment_status', __('支付状态'))->using([1=>'待付款',2=>'已付款',3=>'退款中',4=>'已退款',5=>'待退款'])->label([1=>'warning',2=>'success',3=>'info',4=>'danger',5=>'default']);
        $grid->column('total_amount', __('订单总金额'))->display(function ($money){
            return $money/100;
        });
        $grid->column('payment_amount', __('用户实际支付的金额'))->display(function ($money){
            return $money/100;
        });
        $grid->column('discount_amount', __('折扣金额'))->display(function ($money){
            return $money/100;
        });
        $grid->column('is_evaluates', __('评价详情'))->expand(function ($model){
            $infos = $model->evaluate()->get()->map(function ($info){
                return $info->only(['order_id','content','status']);
            });
            $infos = $infos->toArray();
            foreach ($infos as $key => $value)
            {
                if (!empty($infos[$key]))
                {
                    if ($infos[$key]['status'] == 1)
                    {
                        $infos[$key]['status'] = '待审核';
                    }else if ($infos[$key]['status'] == 2)
                    {
                        $infos[$key]['status'] = '审核成功';
                    }else{
                        $infos[$key]['status'] = '审核拒绝';
                    }
                }
            }
            return new Table(['订单id','评价内容','评价状态'],$infos);
        });
        $grid->column('evaluate.score', __('订单评分'));
//        $grid->column('file_path','录音')->display(function (){
//            return 'callLog/1.mp3';
//        })->downloadable('/upload');
        $grid->column('order_notes', __('订单备注'));
        $grid->column('payment_time', __('支付时间'))->display(function ($time){
            if ($time == 0)
            {
                return '';
            }else
            {
                return date('Y-m-d H:i:s',$time);
            }
        });
        $grid->column('receiving_time', __('接单时间'))->display(function ($time){
            if ($time == 0)
            {
                return '';
            }else
            {
                return date('Y-m-d H:i:s',$time);
            }
        });
        $grid->column('end_time', __('订单完成时间'))->display(function ($time){
            if ($time == 0)
            {
                return '';
            }else
            {
                return date('Y-m-d H:i:s',$time);
            }
        });
        $grid->column('created_at','创建时间')->hide();
        return $grid;
    }

    /**
     * Make a show builder.
     *
     * @param mixed $id
     * @return Show
     */
    protected function detail($id)
    {
        $show = new Show(Order::findOrFail($id));
        $show->field('id', __('Id'));
        $show->field('user_id', __('用户id'));
        $show->field('user.nickname', __('用户姓名'));
        $show->field('docter_id', __('医生id'));
        $show->field('docter.name', __('医生姓名'));
        $show->field('patient_id', __('患者id'));
        $show->field('orderPatient.name', __('患者姓名'));
        $show->field('organization_id', __('机构id'));
        $show->field('organization.name', __('机构名'));
        $show->field('order_sn', __('订单号'));
        $show->field('product_type', __('产品类型'))->using([1=>'电话咨询',2=>'图文咨询']);
        $show->field('payment_type', __('支付类型'))->using([1=>'微信支付',2=>'余额支付']);
        $show->field('order_status', __('订单状态'))->using([1=>'未支付',2=>'待接单',3=>'进行中',4=>'已完成',5=>'已取消']);
        $show->field('payment_status', __('支付状态'))->using([1=>'待付款',2=>'已付款',3=>'退款中',4=>'已退款']);
        $show->field('total_amount', __('	订单总金额'))->as(function ($money){
            return $money/100;
        });
        $show->field('payment_amount', __('用户实际支付的金额'))->as(function ($money){
            return $money/100;
        });
        $show->field('discount_amount', __('折扣金额'))->as(function ($money){
            return $money/100;
        });
        $show->field('payment_time', __('支付时间'))->as(function ($time){
            if($time == 0)
            {
                return '';
            }
            else
            {
                return date('Y-m-d H:i:s',$time);
            }
        });
        $show->field('receiving_time', __('接单时间'))->as(function ($time){
            if($time == 0)
            {
                return '';
            }
            else
            {
                return date('Y-m-d H:i:s',$time);
            }
        });
        $show->field('end_time', __('订单完成时间'))->as(function ($time){
            if($time == 0)
            {
                return '';
            }
            else
            {
                return date('Y-m-d H:i:s',$time);
            }
        });
        $show->field('created_at', __('创建时间'));
        $show->field('updated_at', __('更新时间'));


        return $show;
    }

    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {
        $form = new Form(new Order());

        $form->number('user_id', __('User id'));
        $form->number('docter_id', __('Docter id'));
        $form->number('patient_id', __('Patient id'));
        $form->number('organization_id', __('Organization id'));
        $form->text('order_sn', __('Order sn'));
        $form->switch('payment_type', __('Payment type'))->default(1);
        $form->switch('product_type', __('Product type'))->default(1);
        $form->switch('order_status', __('Order status'))->default(1);
        $form->switch('payment_status', __('Payment status'))->default(1);
        $form->number('total_amount', __('Total amount'));
        $form->number('payment_amount', __('Payment amount'));
        $form->number('discount_amount', __('Discount amount'));
        $form->number('payment_time', __('Payment time'));
        $form->number('outtime', __('Outtime'));
        $form->number('receiving_time', __('Receiving time'));

        return $form;
    }
    function message(Content $content,Request $request)
    {
//        dd($request->all());
        $user = $request->input('user_id');
        $docter = $request->input('docter_id');
        $start = $request->input('start');
        $end = $request->input('end');
        $str_docter = 'doctor_'.$user;
        $str_user = 'member_'.$docter;
//        $docter = 10086;
//        $user = 29068;
//        $start = 1614433272;
//        $end = 1614433703;
//        $str_docter = 'doctor_'.$docter;
//        $str_user = 'member_'.$user;
        $user_arr = ImMessage::whereBetween('create_time',[$start,$end])
            ->where('senderId',$str_user)
            ->get()->toArray();
        $docter_arr = ImMessage::whereBetween('create_time',[$start,$end])
            ->where('senderId',$str_docter)
            ->get()->toArray();
        $arr = array_merge($user_arr,$docter_arr);
        array_multisort(array_column($arr,'create_time'),SORT_ASC,$arr);
        $content = new Content();
        $order_id = $request->input('order_id');
        $content->title('图文咨询聊天记录 ');
        $content->description('订单号'.$order_id);
        Admin::js('jquery-3.5.1.min.js');
        $content->body('<iframe src="/admin/message_view?docter_id='.$docter.'
                                                                &user='.$user.'
                                                                &start='.$start.'
                                                                &end='.$end.'
                                                                &order_id='.$order_id.'" style="width: 100%;height:800px;border: none"></iframe>');
        return $content;
    }
    public function message_view(Request $request)
    {
        $start = $request->input('start');
        $end = $request->input('end');
        $docter = $request->input('docter_id');
        $user = $request->input('user');
        $order_id = $request->input('order_id');
        $str_docter = 'doctor_'.$docter;
        $str_user = 'member_'.$user;
        $user_arr = ImMessage::whereBetween('create_time',[$start,$end])
            ->where('senderId',$str_user)
            ->get()->toArray();
        $docter_arr = ImMessage::whereBetween('create_time',[$start,$end])
            ->where('senderId',$str_docter)
            ->get()->toArray();
        $arr = array_merge($user_arr,$docter_arr);
        array_multisort(array_column($arr,'create_time'),SORT_ASC,$arr);
        return view('admin.message',compact('arr','order_id','docter','user'));
    }
}
