<?php

namespace App\Admin\Controllers\OrdersManagement;

use App\Admin\Actions\backstage\Docters\Team;
use App\Admin\Actions\backstage\Orders\Evaluate;
use App\Admin\Actions\backstage\Orders\ServicePack;
use App\Admin\Actions\backstage\Orders\ServicePackOrderList;
use App\Models\Order;
use App\Admin\Actions\backstage\Orders\OrderDetails;
use Encore\Admin\Controllers\AdminController;
use App\Admin\Actions\backstage\User\MapDepot;
use App\Admin\Actions\backstage\User\Suggests;
use Encore\Admin\Form;
use Encore\Admin\Grid;
use Encore\Admin\Show;

class ServicePackOrderController extends AdminController
{
    /**
     * Title for current resource.
     *
     * @var string
     */
    protected $title = '服务包开通订单';

    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        $grid = new Grid(new Order());
        $grid->disableCreateButton();
        $grid->model()->wherein('product_type',[6]);
        //筛选
        $grid->filter(function ($filter){
            $filter->disableIdFilter();

                $filter->like('user.nickname','用户姓名');
                $filter->equal('user.phone','用户电话');
                $filter->like('orderPack.pack_name','服务包名称');
                $filter->like('patient.name','患者姓名');
                $filter->equal('order_status','订单状态')->radio(
                    [
                        ''=>'不限',
                        1=>'未支付',
                        2=>'待接单',
                        3=>'进行中',
                        4=>'已完成',
                        5=>'已取消'
                    ]
                );
                $filter->where(function ($query){
                   $query->whereHas('orderPack',function ($query){
                       $query->where('team_id','like',"%{$this->input}%");
                   });
                },'医生团队')->select(\App\Models\Team::where('status',1)->pluck('name','id'));
            $filter->timestampBetween('payment_time', "支付时间")->datetime();

            });
        //操作
        $grid->actions(function ($actions) {
            $actions->disableView();
            // 去掉删除
            $actions->disableDelete();
            // 去掉编辑
            $actions->disableEdit();
            $actions->add(new ServicePack());
            $actions->add(new ServicePackOrderList());
        });
        $grid->export(function ($export) {
            $export->filename('服务包开通订单');
        });
        $status_arr = Order::getStatus();
        $grid->model()->orderBy('id','desc');
        $grid->column('id', __('Id'))->sortable();
        $grid->column('order_sn', __('订单编号'));
        $grid->column('user.nickname', __('用户姓名'));
        $grid->column('patient.name', __('患者姓名'));
        $grid->column('patient_id', __('患者id'))->hide();
        $grid->column('user.phone', __('用户电话'));
        $grid->column('orderPack.service_pack_id', __('服务包id'));
        $grid->column('orderPack.pack_name', __('服务包名称'));
        $grid->column('orderPack.pack_price', __('服务包价格'))->display(function ($money){
            return $money/100;
        });
        $grid->column('orderPack.team_id', __('医生团队'))->display(function ($team){
            if (empty($team))
            {
                return '无';
            }else
            {
                $res = \App\Models\Team::whereIn('id',$team)->pluck('name')->toArray();
                return $res;
            }
        })->label('info');
        $grid->column('product_type', __('产品类型'))->using([6=>'服务包订单']);
        $grid->column('payment_type', __('支付方式'))->using([1=>'微信支付',2=>'余额支付']);
        $grid->column('order_status', __('订单状态'))->display(function ($w) use ($status_arr) {
            $info = $status_arr[intval($w)];
            if($w == 1 || $w == 2){
                return '<span class="label label-warning">'.$info.'</span>';
            } else if( $w == 4 ){
                return '<span class="label label-success">'.$info.'</span>';
            } else if($w == 7 || $w == 3 ){
                return '<span class="label label-info">'.$info.'</span>';
            } else if($w == 6){
                return '<span class="label label-danger">'.$info.'</span>';
            } else {
                return '<span class="label label-default">'.$info.'</span>';
            }
        });
        $grid->column('payment_status', __('支付状态'))->using([1=>'待付款',2=>'已付款',3=>'退款中',4=>'已退款'])->label([1=>'warning',2=>'success',3=>'info',4=>'danger']);
        $grid->column('total_amount', __('订单总金额'))->display(function ($money){
            return $money/100;
        });
        $grid->column('payment_amount', __('用户实际支付的金额'))->display(function ($money){
            return $money/100;
        });
        $grid->column('discount_amount', __('折扣金额'))->display(function ($money){
            return $money/100;
        });
        $grid->column('order_notes', __('订单备注'));
        $grid->column('payment_time', __('支付时间'))->display(function ($time){
            return date('Y-m-d H:i:s',$time);
        });
        return $grid;
    }

    /**
     * Make a show builder.
     *
     * @param mixed $id
     * @return Show
     */
    protected function detail($id)
    {
        $show = new Show(Order::findOrFail($id));
        $show->field('id', __('Id'));
        $show->field('user_id', __('用户id'));
        $show->field('user.nickname', __('用户姓名'));
        $show->field('docter_id', __('医生id'));
        $show->field('docter.name', __('医生姓名'));
        $show->field('patient_id', __('患者id'));
        $show->field('orderPatient.name', __('患者姓名'));
        $show->field('organization_id', __('机构id'));
        $show->field('organization.name', __('机构名'));
        $show->field('order_sn', __('订单号'));
        $show->field('product_type', __('产品类型'))->using([6=>'服务包订单']);
        $show->field('payment_type', __('支付类型'))->using([1=>'微信支付',2=>'余额支付']);
        $show->field('order_status', __('订单状态'))->using([1=>'未支付',2=>'待接单',3=>'进行中',4=>'已完成',5=>'已取消']);
        $show->field('payment_status', __('支付状态'))->using([1=>'待付款',2=>'已付款',3=>'退款中',4=>'已退款']);
        $show->field('total_amount', __('	订单总金额'))->as(function ($money){
            return $money/100;
        });
        $show->field('payment_amount', __('用户实际支付的金额'))->as(function ($money){
            return $money/100;
        });
        $show->field('discount_amount', __('折扣金额'))->as(function ($money){
            return $money/100;
        });
        $show->field('payment_time', __('支付时间'))->as(function ($time){
            if($time == 0)
            {
                return '';
            }
            else
            {
                return date('Y-m-d H:i:s',$time);
            }
        });
        $show->field('receiving_time', __('接单时间'))->as(function ($time){
            if($time == 0)
            {
                return '';
            }
            else
            {
                return date('Y-m-d H:i:s',$time);
            }
        });
        $show->field('end_time', __('订单完成时间'))->as(function ($time){
            if($time == 0)
            {
                return '';
            }
            else
            {
                return date('Y-m-d H:i:s',$time);
            }
        });
        $show->field('created_at', __('创建时间'));
        $show->field('updated_at', __('更新时间'));

        return $show;
    }
}
