<?php

namespace App\Exceptions;

use Exception;
use Illuminate\Foundation\Exceptions\Handler as ExceptionHandler;
use Illuminate\Validation\ValidationException;

class Handler extends ExceptionHandler
{
    /**
     * A list of the exception types that are not reported.
     *
     * @var array
     */
    protected $dontReport = [
        ExitOutException::class,
    ];

    /**
     * A list of the inputs that are never flashed for validation exceptions.
     *
     * @var array
     */
    protected $dontFlash = [
        'password',
        'password_confirmation',
    ];

    /**
     * Report or log an exception.
     *
     * @param  \Exception  $exception
     * @return void
     */
    public function report(Exception $exception)
    {
        parent::report($exception);
    }

    /**
     * Render an exception into an HTTP response.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \Exception  $exception
     * @return \Illuminate\Http\JsonResponse
     */
    public function render($request, Exception $exception)
    {
        //如果路由中含有“api/”，则说明是一个 api 的接口请求
        if ($request->is("api/v*")) {
            //如果错误是 ValidationException的一个实例，说明是一个验证的错误
            if ($exception instanceof ValidationException) {
                return out(null, 10000, array_values($exception->errors())[0][0]);
            }

            if ($exception instanceof ExitOutException){
                $msg = $exception->getMessage();
                $out = json_decode($msg, true);
                return out($out['data'], $out['status'], $out['message']);
            }

            return out(null, 500, $exception->getMessage());
        }

        return parent::render($request, $exception);
    }
}
